@@ -77,7 +77,7 @@ INTERNALERROR_VPCCGWERROR = 'InternalError.VpcCgwError'
 # An error occurred while calling another service API.
 INTERNALERROR_VPCERROR = 'InternalError.VpcError'
 
-# An error occurred when calling the Woodpecker server.
+# An error occurred while calling another service API.
 INTERNALERROR_WOODSERVERERROR = 'InternalError.WoodServerError'
 
 # Invalid parameter.
@@ -119,7 +119,7 @@ INVALIDPARAMETER_INVALIDCOUNT = 'InvalidParameter.InvalidCount'
 # An individual scaling-out request only applies to task nodes or core nodes.
 INVALIDPARAMETER_INVALIDCOUNTNUM = 'InvalidParameter.InvalidCountNum'
 
-# Container account or container parameter verification error.
+# Error message: Invalid PodParameter.
 INVALIDPARAMETER_INVALIDCUSTOMIZEDPODPARAM = 'InvalidParameter.InvalidCustomizedPodParam'
 
 # Invalid disk size.
@@ -281,6 +281,9 @@ RESOURCENOTFOUND_TKEPRECONDITIONNOTFOUND = 'ResourceNotFound.TKEPreconditionNotF
 # No specified tag found.
 RESOURCENOTFOUND_TAGSNOTFOUND = 'ResourceNotFound.TagsNotFound'
 
+# There is no default specification for the current resource specification.
+RESOURCEUNAVAILABLE_RESOURCESPECNOTDEFAULTSPEC = 'ResourceUnavailable.ResourceSpecNotDefaultSpec'
+
 # There is no default specification for the current resource specification.
 RESOURCEUNAVAILABLE_RESOURCESPEC_NOTDEFAULTSPEC = 'ResourceUnavailable.ResourceSpec_NotDefaultSpec'
 
@@ -298,3 +301,6 @@ UNKNOWNPARAMETER = 'UnknownParameter'
 
 # Unsupported operation.
 UNSUPPORTEDOPERATION = 'UnsupportedOperation'
+
+# This operation is not supported.
+UNSUPPORTEDOPERATION_SERVICENOTSUPPORT = 'UnsupportedOperation.ServiceNotSupport'
